# История изменений

**0.1.4**

- Добавление MANIFEST.in для корректной сборки и дальнейшей установки пакета;

**0.1.3**

- Добавление возможности выполнения отложенного сохранения объектов, даже в случае наличия ошибок в процессе работы функции;
- Добавление свойств helper и global_helper в соответствующие миксины;
- Добавлена возможность расширения  запускаемого объекта перед и после валидации;
- Добавлен декоратор для методов функции, запускаемых только в случае отсутствия зарегистрированных ошибок, полученных в процессе работы функции.

**0.1.2**

- Поднята версия Django до 2.2.4

**0.1.1**

- Добавление ссылок на документацию.